#### Beispiel Datenanalyse Dummies-Buch ####

#### Daten einlesen ####
library(openxlsx)
dat1 <- read.xlsx("Beispieldaten_unbereinigt.xlsx")
dat1$Geschlecht <- factor(dat1$Geschlecht) # kategoriale als Faktoren speichern
dat1$Schulabschluss <- factor(dat1$Schulabschluss) 
dat1$Gruppe <- factor(dat1$Gruppe) 
dat1$erfolg <- factor(dat1$erfolg) 
dat1$anstellung <- factor(dat1$anstellung) 
dat1$empf_t1 <- factor(dat1$empf_t1) 
dat1$empf_t2 <- factor(dat1$empf_t2) 

#### Datencheck ####
summary(dat1)
dat1$Alter <- ifelse(dat1$Alter > 100, NA, dat1$Alter) # Alterswerte über 100 durch NA ersetzen
summary(dat1)

#### Stichprobenbeschreibung gesamt ####
table(dat1$Geschlecht) # absolut
table(dat1$Geschlecht)/sum(table(dat1$Geschlecht)) #relativ
table(dat1$Schulabschluss) # absolut
table(dat1$Schulabschluss)/sum(table(dat1$Schulabschluss)) #relativ
library(psych) # für describe und später für alpha, ICC, describe
describe(dat1$Alter)

#### Stichprobenbeschreibung gruppiert ####
table(dat1$Geschlecht, dat1$Gruppe) # absolut
prop.table(table(dat1$Geschlecht, dat1$Gruppe), 2) #relativ
table(dat1$Schulabschluss, dat1$Gruppe) # absolut
prop.table(table(dat1$Schulabschluss, dat1$Gruppe), 2) #relativ

#### Gütekriterien ####
## teils umkodierte Items verwenden

### Interne Konsistenz: raw_alpha
### Trennschärfe: r.drop
alpha(cbind(dat1$A1_recode, dat1$A2, dat1$A3, dat1$A4, dat1$A5)) 
alpha(cbind(dat1$C1, dat1$C2, dat1$C3, dat1$C4_recode, dat1$C5_recode)) 
alpha(cbind(dat1$E1_recode, dat1$E2_recode, dat1$E3, dat1$E4, dat1$E5))
alpha(cbind(dat1$N1, dat1$N2, dat1$N3, dat1$N4, dat1$N5))
alpha(cbind(dat1$O1, dat1$O2_recode, dat1$O3, dat1$O4, dat1$O5_recode))

### Item-Schwierigkeit
my_schwier <- function(x){
  return(mean(x-1)/max(x-1))
}
dat_items <- cbind(dat1$A1_recode, dat1$A2, dat1$A3, dat1$A4, dat1$A5,
                   dat1$C1, dat1$C2, dat1$C3, dat1$C4_recode, dat1$C5_recode,
                   dat1$E1_recode, dat1$E2_recode, dat1$E3, dat1$E4, dat1$E5, 
                   dat1$N1, dat1$N2, dat1$N3, dat1$N4, dat1$N5, 
                   dat1$O1, dat1$O2_recode, dat1$O3, dat1$O4, dat1$O5_recode)
apply(dat_items, 2, my_schwier)

### Intra-Rater-Reliabilität
## Beurteilung der Kommunikationsfähigkeit durch 3 Rater (r1, r2, r3) zu t0, metrische Skala
ICC(cbind(dat1$com_t0_r1, dat1$com_t0_r2, dat1$com_t0_r3)) 

#### Skalen bilden ####
dat1$Vertraeglichkeit <- apply(cbind(dat1$A1_recode, dat1$A2, dat1$A3, dat1$A4, dat1$A5), 1, mean)  
dat1$Gewissenhaftigkeit <- apply(cbind(dat1$C1, dat1$C2, dat1$C3, dat1$C4_recode, dat1$C5_recode), 1, mean)  
dat1$Extraversion <- apply(cbind(dat1$E1_recode, dat1$E2_recode, dat1$E3, dat1$E4, dat1$E5), 1, mean)  
dat1$Neurotizismus <- apply(cbind(dat1$N1, dat1$N2, dat1$N3, dat1$N4, dat1$N5), 1, mean)  
dat1$Offenheit <- apply(cbind(dat1$O1, dat1$O2_recode, dat1$O3, dat1$O4, dat1$O5_recode), 1, mean)  

#### Beispiele zur deskriptiven Analyse #####
# Kreuztabelle
t1 <- table(dat1$Geschlecht, dat1$erfolg)
t1
prop.table(t1,1)

# Kendall Korrelation
cor(dat1$laune_t1, dat1$laune_t2, use="complete.obs", method="kendall")

# Spearman Korrelation
cor(dat1$laune_t1, dat1$laune_t2, use="complete.obs", method="spearman")

# Pearson Korrelation
cor(dat1$com_t1, dat1$Neurotizismus, use="complete.obs", method="pearson")

# Deskriptive metrisch, Lagemaß, Streuung, gruppiert oder über die Zeit
summary(cbind(dat1$com_t0_r3, dat1$com_t1, dat1$com_t2))
describe(cbind(dat1$com_t0_r3, dat1$com_t1, dat1$com_t2))
describeBy(dat1$com_t1, group=dat1$Geschlecht, mat=T)

# Deskriptive ordinal, gruppiert
dat1_m <- subset(dat1, dat1$Geschlecht =="m")
dat1_w <- subset(dat1, dat1$Geschlecht =="w")
dat1_d <- subset(dat1, dat1$Geschlecht =="d")

summary(dat1_m$laune_t1)
summary(dat1_w$laune_t1)
summary(dat1_d$laune_t1)
describeBy(dat1$laune_t1, group = dat1$Geschlecht, mat=T)

# Kaplan Meier und Mediane Überlebenszeit
dat1$anstellung.num <- as.numeric(dat1$anstellung) # muss als Zahl verwendet werden
library(survival)
anstellung_surv <- Surv(dat1$monate, dat1$anstellung.num)

fit_gruppe <- survfit(anstellung_surv ~ dat1$Gruppe)
fit_gruppe
summary(fit_gruppe)

#### Abbildungen ####
# Balken
barplot(t(t1), beside=T, ylim=c(0,60), legend=T, xlim=c(0,12),
        xlab="Geschlecht", ylab="Häufigkeit")

# Streudiagramm
plot(dat1$Neurotizismus, dat1$com_t2, xlab="Neurotizismus", ylab="Kommunikationsfähigkeit t2")
abline(lm(dat1$com_t2 ~ dat1$Neurotizismus), col="darkgrey")

# Mittelwertdiagramm mit Fehlerbalken
# M und SD
des1 <- describeBy(dat1$com_t2, group=dat1$Gruppe, mat=T)

library(ggplot2) # für ggplot
library(jtools) # für theme_apa
library(gridExtra) # für gridarrange
# mit 1 SD
p1 <- ggplot(des1, aes(x=group1, y=mean)) +
  geom_point(size=2) +
  geom_errorbar(aes(ymin=mean-sd, ymax=mean+sd), width=.1) +
  theme_apa() +
  xlab("") +
  ylab("Kommunikation t2 [M +/- 1SD]") +
  ylim(-25,100)
# mit 2 SD
p2 <- ggplot(des1, aes(x=group1, y=mean)) +
  geom_point(size=2) +
  geom_errorbar(aes(ymin=mean-2*sd, ymax=mean+2*sd), width=.1) +
  theme_apa() +
  xlab("") +
  ylab("Kommunikation t2 [M +/- 2SD]") +
  ylim(-25,100)
# mit 95 % CI
p3 <- ggplot(des1, aes(x=group1, y=mean)) +
  geom_point(size=2) +
  geom_errorbar(aes(ymin=mean-1.96*se, ymax=mean+1.96*se), width=.1) +
  theme_apa() +
  xlab("") +
  ylab("Kommunikation t2 [M, 95 % CI]") +
  ylim(-25,100)
# mit SE
p4 <- ggplot(des1, aes(x=group1, y=mean)) +
  geom_point(size=2) +
  geom_errorbar(aes(ymin=mean-se, ymax=mean+se), width=.1) +
  theme_apa() +
  xlab("") +
  ylab("Kommunikation t2 [M +/- 1SE]")+
  ylim(-25,100)

grid.arrange(p1, p2, p3, p4, nrow = 2)

# Boxplot
boxplot(dat1$laune_t1 ~ dat1$erfolg, ylab="Laune t1", xlab="Erfolg", col="white")
boxplot(dat1$com_t0_r2, ylab="X", col="white")

# Kaplan Meier
plot(fit_gruppe, col=c("grey", "black"), lty=c(1, 2), lwd=3,
     ylab = "Anteil ohne Anstellung", xlab="Monate")
legend(6.5, 1, legend=c("C", "T"), 
       fill=c("grey", "black"))

### Beispiele zu Effektstärkemaßen ####
## großer Effekt, nicht signifikant ####
# Männer ohne allgemeinen Schulabschluss
dat1_auswahl <- dat1[dat1$Geschlecht == "m" & dat1$Schulabschluss=="ohne allgemeinen Schulabschluss",]
wilcox.test(dat1_auswahl$com_t0_r3, dat1_auswahl$com_t2)
describe(cbind(dat1_auswahl$com_t0_r3, dat1_auswahl$com_t2))

library(rstatix) # für wilcox_effsize
# Daten für wilcox_effsize umformatieren
dat_wilc <- data.frame(cbind(c(rep("t0", 8), rep("t2", 8)), c(dat1_auswahl$com_t0_r3, dat1_auswahl$com_t2)))
dat_wilc <- dat_wilc[!is.na(dat_wilc$X2),]
dat_wilc$X1 <- factor(dat_wilc$X1)
dat_wilc$X2 <- as.numeric(dat_wilc$X2)

wilcox_effsize(data= dat_wilc, X2 ~ X1, paired=T)

##### kleiner Effekt, signifikant ####
cor.test(dat1$Neurotizismus, dat1$com_t0_r2, use="complete.obs", method="spearman")

##### Vergleich von Effekten #####
library(effsize)
dat_C <- subset(dat1, dat1$Gruppe == "C")
dat_T <- subset(dat1, dat1$Gruppe == "T")

cohen.d(dat_C$com_t1, dat_C$com_t2)
cohen.d(dat_T$com_t1, dat_T$com_t2)

##### Voraussetzungen untersuchen ######
#### Zellbesetzung ####
table(dat1$Geschlecht, dat1$anstellung)
c1 <- chisq.test(table(dat1$Geschlecht, dat1$anstellung))
c1$expected

##### Normalverteilung ####
qqnorm(dat1$Alter)
qqline(dat1$Alter)

par(mfrow=c(1,3))
qqnorm(dat1$Neurotizismus)
qqline(dat1$Neurotizismus)
qqnorm(dat1$com_t0_r1)
qqline(dat1$com_t0_r1)
qqnorm(dat1$com_t0_r2)
qqline(dat1$com_t0_r2)
par(mfrow=c(1,1))

#### Ähnliche Verteilungsform ####
boxplot(dat1$com_t0_r2, dat1$com_t0_r1, names=c("X", "Y"))

par(mfrow=c(1,3))
boxplot(dat1$com_t0_r2, dat1$com_t0_r1, names=c("X", "Y"))
hist(dat1$com_t0_r2, main="", xlab="X", ylab="Häufigkeit")
hist(dat1$com_t0_r1, main="", xlab="Y", ylab="Häufigkeit")
par(mfrow=c(1,1))

#### Varianzhomogenität #####
describeBy(dat1$Neurotizismus, group = dat1$erfolg, mat=T)
levene_test(dat1, Neurotizismus ~ erfolg)
boxplot(dat1$Neurotizismus ~ dat1$erfolg, xlab=c("Erfolg"), ylab=c("Neurotizismus"))

### Homoskedastizität ####
fit1 <- lm(dat1$Neurotizismus ~ dat1$Offenheit)
plot(fit1)

### Sphärizität #####
library(ez) # für ezANOVA
library(reshape2) # für melt

# Daten umformatieren ins Long-Format
dat1_mwh <- dat1[,c(1,2,3,4,5,31,34,35)]
dat1_l <- melt(dat1_mwh, id.vars=c("ID", "Geschlecht", 
                                   "Alter", "Schulabschluss", "Gruppe"),
                   variable.name="Messung",
                   value.name="com")
dat1_l$Messung <- factor(dat1_l$Messung, labels=c("t0", "t1", "t2"))

fit2 <- ezANOVA(data=dat1_l, dv=.(com), wid=.(ID),  within=.(Messung), type=3, detailed=T)
fit2

### Linearität ###
plot(log(dat1$com_t0_r1), dat1$com_t2, xlab="X", ylab="Y")

### Loglinearität prüfen ####
defaultW <- getOption("warn") 
options(warn = -1) 
dat1$log_alter <- log(dat1$Alter) # Logtranssformation von Alter
fit4 <- glm(dat1$erfolg ~ dat1$Alter + dat1$Alter:dat1$log_alter, family = binomial, na.action = na.exclude)
summary(fit4)
options(warn = defaultW)

### keine Ausreißer ####
## Beispiel: Prüfen der Residuen im linearen Regressionsmodell auf Ausreißer
# Lineares Regressionsmodell aufstellen: Abhängige Variable als Differenzvariable berechnen
dat1$Diff_com <- dat1$com_t2 - dat1$com_t0_r3
# Modell rechnen
fit8 <- lm(Diff_com ~ Gruppe + Vertraeglichkeit + Gewissenhaftigkeit + 
             Extraversion + Offenheit + Neurotizismus, data = dat1)
# Standardisierte Residuen des Modells betrachten, die größer als 2 oder kleiner als -2 sind
rstandard(fit8)[rstandard(fit8)> 2 |rstandard(fit8) < -2]

### keine Multikollinearität ####
cor(cbind(dat1$Neurotizismus, dat1$Offenheit , dat1$Vertraeglichkeit , dat1$Extraversion , dat1$Gewissenhaftigkeit , dat1$Alter), use="complete")
library(car) # für vif
fit5 <- lm(dat1$com_t0_r3 ~ dat1$Neurotizismus + dat1$Offenheit + dat1$Vertraeglichkeit + dat1$Extraversion + dat1$Gewissenhaftigkeit + dat1$Alter)
vif(fit5)

### Unabhängigkeit der Residuen ####
# Beispiel: Prüfen der Unabhängigkeit der Residuen im linearen Regressionsmodell: Durbin Watson Wert
dwt(fit8)

######## Einfache Signifikanztests ########
#### McNemar #####
mcnemar.test(dat1$empf_t1, dat1$empf_t2)

#### Fishers Exakter Test ####
fisher.test(dat1$erfolg, dat1$Gruppe)

#### Chi-Quadrat-Unabhängigkeits-Test ####
chisq.test(table(dat1$Schulabschluss, dat1$erfolg))

#### Korrelation ####
cor.test(dat1$Gewissenhaftigkeit, dat1$Vertraeglichkeit, method="kendall")
cor.test(dat1$Gewissenhaftigkeit, dat1$Vertraeglichkeit, method="spearman")

plot(dat1$Gewissenhaftigkeit, dat1$Extraversion)

qqnorm(dat1$Gewissenhaftigkeit)
qqline(dat1$Gewissenhaftigkeit)
qqnorm(dat1$Extraversion)
qqline(dat1$Extraversion)
cor.test(dat1$Gewissenhaftigkeit, dat1$Extraversion, method="pearson")

### Lograng-Test ####
survdiff(anstellung_surv ~ dat1$Gruppe)

#### Einstichproben Wilcoxon #####
wilcox.test(dat1$Alter, mu = 25)

#### Einstichproben t-Test #####
qqnorm(dat1$Gewissenhaftigkeit)
qqline(dat1$Gewissenhaftigkeit)
describe(dat1$Gewissenhaftigkeit)

t.test(dat1$Gewissenhaftigkeit, mu=3)

#### Mann-Whitney-U-Test #####
describeBy(dat1$com_t1, group=dat1$Gruppe, mat=T)
wilcox.test(dat1$com_t1 ~ dat1$Gruppe)

#### t-Test ####
qqnorm(dat1$Gewissenhaftigkeit[dat1$Gruppe=="T"])
qqline(dat1$Gewissenhaftigkeit[dat1$Gruppe=="T"])
qqnorm(dat1$Gewissenhaftigkeit[dat1$Gruppe=="C"])
qqline(dat1$Gewissenhaftigkeit[dat1$Gruppe=="C"])

leveneTest(dat1$Gewissenhaftigkeit ~ dat1$Gruppe)

t.test(dat1$Gewissenhaftigkeit ~ dat1$Gruppe, var.equal=T)

### Wilcoxon gepaart ####
wilcox.test(dat1$com_t1, dat1$com_t2, paired=T)

#### t-Test gepaart #####
t.test(dat1$com_t1, dat1$com_t2, paired=T)

#### Kruskal-Wallis-Test #####
describeBy(dat1$laune_t1, group=dat1$Schulabschluss, mat=T) # Ähnliche Verteilung
kruskal.test(dat1$laune_t1~dat1$Schulabschluss)

#### Einfaktorielle ANOVA #####
leveneTest(dat1$Gewissenhaftigkeit ~ dat1$Schulabschluss)
fit6 <- aov(dat1$Gewissenhaftigkeit ~ dat1$Schulabschluss)
summary(fit6)

#### Friedman-Test ######
mat1 <- cbind(dat1$com_t0_r3, dat1$com_t1, dat1$com_t2)
friedman.test(mat1)

#### Messwiederholungs-ANOVA #####
fit2 <- ezANOVA(data=dat1_l, dv=.(com), wid=.(ID),  within=.(Messung), type=3, detailed=T)
fit2

#### Conover Post-Hoc-Test nach Friedman #####
library(PMCMRplus)
frdAllPairsConoverTest(y = dat1_l$com, groups = dat1_l$Messung,
                       blocks = dat1_l$ID, p.adjust.method="holm")


#### Mehrfaktorielle ANOVA #####
fit7 <- ezANOVA(data=dat1_l, dv=.(com), wid=.(ID),  
                within=.(Messung), between=.(Gruppe), type=3, detailed=T)
fit7

#### Profilplots ####
par(mfrow=c(2,1))
interaction.plot(x.factor = dat1_l$Gruppe, #x-Achse
                 trace.factor = dat1_l$Messung, #Linien
                 response = dat1_l$com, #Y-Achse
                 fun = mean, #Lagemaß
                 ylab = "Kommunikationsfähigkeit",
                 xlab = "Gruppe",
                 col = c("darkorange", "blue3", "deeppink"),
                 lty = 1, #line type
                 lwd = 2, #line width
                 trace.label = "Zeit")
interaction.plot(x.factor = dat1_l$Messung, #x-Achse
                 trace.factor = dat1_l$Gruppe, #Linien
                 response = dat1_l$com, #Y-Achse
                 fun = mean, #Lagemaß
                 ylab = "Kommunikationsfähigkeit",
                 xlab = "Zeit",
                 col = c("coral1", "blue3"),
                 lty = 1, #line type
                 lwd = 2, #line width
                 trace.label = "Gruppe")
par(mfrow=c(1,1))

##### Lineare Regression #######
## Veränderungsvariable bilden (t0 bis t2),
dat1$Diff_com <- dat1$com_t2 - dat1$com_t0_r3

fit8 <- lm(Diff_com ~ Gruppe + Vertraeglichkeit + Gewissenhaftigkeit + 
             Extraversion + Offenheit + Neurotizismus, data = dat1)
summary(fit8)
# (Teile der) Voraussetzungen prüfen
par(mfrow=c(2,2))
plot(fit8)
par(mfrow=c(1,1))

##### Binär logistische Regression ########
library(fmsb) # Nagelkerkes R Quadrat

fit9 <- glm(erfolg ~ com_t2 + Alter + Schulabschluss, data = dat1, family=binomial())
summary(fit9)

# Odds Ratios
exp(fit9$coefficients)

# Chi-Squared-Test für den Model-Fit
chi_fit2 <- fit9$null.deviance-fit9$deviance
chi_fit2
df_fit2 <- fit9$df.null-fit9$df.residual
df_fit2
1-pchisq(chi_fit2, df_fit2)# p-Wert des Chi-Quadrat-Tests

# Nagelkerkes R2
NagelkerkeR2(fit9)

#### Explorative Methoden #####
### Explorative Faktorenanalyse #####
library(psy)
library(nFactors)

# Datenauswahl nur Items und vollstaendige Faelle
dat_efa <- dat1[,6:30]
dat_efa <- dat_efa[complete.cases(dat_efa), ]

## Deskriptive Analyse als Datencheck (keine Ausreisser)

describe(dat_efa)

### Faktorenanalyse ###

# Bartlett-Test
cortest.bartlett(dat_efa)

# KMO und MSA
KMO(dat_efa)

# Anzahl Faktoren mit Parallelanalyse
ev <- eigen(cor(dat_efa)) 
ap <- parallel(subject=nrow(dat_efa),var=ncol(dat_efa), rep=100, cent=.05)
nS <- nScree(x=ev$values, aparallel=ap$eigen$qevpea)

plotnScree(nS)

## ML-Faktorenanalyse
# 5 Faktoren
# Varimax-Rotation

efa1 <- factanal(dat_efa, 5, rotation="varimax")

# Ergebnisse ausgeben mit 2 Nachkommastellen und Faktorladungen < 0,3 unterdrueckt
print(efa1, digits=2, cutoff=.3)

# Kommunalitaeten
1-efa1$uniquenesses

# Screeplot
scree.plot(efa1$correlation)

### Clusteranalyse #####

# Datenauswahl nur für Clusteranalyse zu verwendenden Variablen und vollstaendige Faelle
dat_clu <- dat1[,c(1,43:47)] # Persönlichkeitsmerkmale und ID
dat_clu <- dat_clu[complete.cases(dat_clu), ]

# Standardisieren
dat_clu_scaled <- cbind(ID=dat_clu$ID, scale(dat_clu[,2:6]))

### Hierarchische Clusteranalyse ###
# Distanzen bilden
dist1 <- dist(dat_clu_scaled[,2:6], method="euclidean") # alternative Methoden: maximum, manhattan, canberra, binary, minkowski

# Clustern
fit9 <- hclust(dist1, method="ward.D2") # alternative Methoden: ward.D, single, complete, average, mcquitty, median, centroid

# Dendrogram
plot(fit9, hang=-1, labels=dat_clu$ID, cex=.7)

# 4-Cluster-Lösung speichern
dat_clu$clus1 <- cutree(fit9, k=4)

# Cluster im Dendrogram markieren
rect.hclust(fit9, k=4, border="red")

# Cluster mit Eigenschaften bezüglich der Clustervariablen beschreiben
describeBy(dat_clu[,2:6], group=dat_clu$clus1, mat=T)
# Boxplots
par(mfrow=c(2,3))
for(i in 2:6){
  boxplot(dat_clu[,i] ~ dat_clu$clus1, ylab = names(dat_clu[i]), xlab = "Cluster")
}
par(mfrow=c(1,1))

### K-Means Clusteranalyse ###

# Anzahl der Cluster festlegen
# Fehlerquadratsumme für verschiedene Clusterlösungen berechnen
wss.fit2 <- (nrow(dat_clu_scaled[,2:6])-1)*sum(apply(dat_clu_scaled[,2:6],2,var))
for (i in 2:15){
  wss.fit2[i] <- sum(kmeans(dat_clu_scaled[,2:6], centers=i)$withinss)
}
# Fehlerquadratsumme gegen Anzahl Cluster plotten
plot(1:15, wss.fit2, type="b", xlab="Anzahl Cluster",
     ylab="Fehlerquadratsumme")

# 5 Cluster-Lösung mit 25 zufälligen initialen Clusterzentren
fit10 <- kmeans(dat_clu_scaled[,2:6], 5, nstart=25)

# Clusterzentren betrachten
aggregate(dat_clu_scaled,by=list(fit10$cluster),FUN=mean)

# Clusterzugehörigkeit speichern
dat_clu$clus2 <- fit10$cluster

# Cluster mit Eigenschaften bezüglich der Clustervariablen beschreiben
describeBy(dat_clu[,2:6], group=dat_clu$clus2, mat=T)
# Boxplots
par(mfrow=c(2,3))
for(i in 2:6){
  boxplot(dat_clu[,i] ~ dat_clu$clus2, ylab = names(dat_clu[i]), xlab = "Cluster")
}
par(mfrow=c(1,1)) 

# Clusterlösungen vergleichen
table(dat_clu$clus2, dat_clu$clus1) 

### Fallzahlplanung und Post-Hoc-Poweranalyse ####
library(pwr)

# Fallzahlplanung für einen t-Test für unabhängige Stichproben bei gleich großen Gruppen
pwr.t.test(d = .6, sig.level = .05, power=.8, type = "two.sample")
# -> 45 Fälle pro Gruppe

# Berechnung der nachweisbaren Effektstärke für einen t-Test für unabhängige Stichproben bei gleich großen Gruppen
pwr.t.test(n = 20, sig.level = .05, power=.8, type = "two.sample")
# -> d = 0.91

# Berechnung der Fallzahl für eine lineare Regression
pwr.f2.test(u = 1, f2 = .02, sig.level = .05, power=.8)
# Fallzahl ist v + 1 + Anzahl der Prädiktoren im Modell. 
# Wenn wie im Beispiel 3 Prädiktoren verwendet werden,
# ergibt sich also eine Fallzahl von 392 + 1 + 3 = 396.

# Post-Hoc-Poweranalyse für einen t-Test für unabhängige Stichproben
pwr.t.test(n = 10, d = .6, sig.level = .05, type = "two.sample")
# -> Power = 0,25

#### Daten speichern ######
#write.xlsx(dat1, "Daten_bearbeitet.xlsx")

